@@ -11,7 +11,6 @@ import geopandas as gpd
 import numpy as np
 import numpy.typing as npt
 import shapely
-from packaging.version import Version
 from scipy.spatial import Voronoi
 from shapely.errors import GEOSException
 
@@ -19,8 +18,6 @@ __author__ = "Serge Rey <sjsrey@gmail.com>"
 
 __all__ = ["voronoi_frames"]
 
-GPD_GE_013 = Version(gpd.__version__) >= Version("0.13.0")
-
 
 def voronoi(points, radius=None):
     """Determine finite Voronoi diagram for a 2-d point set.
@@ -406,11 +403,6 @@ def voronoi_frames(
             if segment != 0:
                 objects.loc[mask_line] = shapely.segmentize(objects[mask_line], segment)
 
-            if not GPD_GE_013:
-                raise ImportError(
-                    "Voronoi tessellation of lines requires geopandas 0.13.0 or later."
-                )
-
             # Remove duplicate coordinates from lines
             objects.loc[mask_line] = (
                 objects.loc[mask_line]
@@ -443,14 +435,8 @@ def voronoi_frames(
 
     # Assign to each input geometry the corresponding Voronoi polygon
     # TODO: check if we still need indexing after shapely/shapely#1968 is released
-    if GPD_GE_013:
-        ids_objects, ids_polygons = polygons.sindex.query(
-            objects, predicate="intersects"
-        )
-    else:
-        ids_objects, ids_polygons = polygons.sindex.query_bulk(
-            objects, predicate="intersects"
-        )
+    ids_objects, ids_polygons = polygons.sindex.query(objects, predicate="intersects")
+
     if mask_poly.any() or mask_line.any():
         # Dissolve polygons
         polygons = (
@@ -466,7 +452,7 @@ def voronoi_frames(
     # ensure validity as union can occasionally produce invalid polygons that may
     # break the intersection below
     if not polygons.is_valid.all():
-        polygons = polygons.make_valid()
+        polygons = shapely.make_valid(polygons)
 
     # Clip polygons if limit is provided
     if limit is not None:
